      SUBROUTINE CRUISECON(cc,icruise,icnum)

C     CRUISECON TAKES A COUNTRY CODE AND A CRUISE CODE AND COMBINES
C     THEM TO CREAT A UNIQUE CODE.  THE LAST 6 DIGITS ARE THE CRUISE
C     CODE, THE 1,000,000 PLACE ON UP IS THE COUNTRY CODE NUMBER

c****************************************************
c
c    Passed Variables:
c
c     cc - country code
c     icruise - cruise code
c     icnum - combined integer code
c
c****************************************************

c****************************************************
c
c    Parameter:
c
c     maxcc - number of NODC country codes
c
c****************************************************

      parameter (maxcc=200)

c****************************************************
c
c    Character Array:
c
c     ncc - all NODC country codes 
c
c***************************************************

      character*2 cc,ncc(maxcc)

      common /countryc/ ncc

      ijk=0
      do 42 lm=1,maxcc
42    if (cc.eq.ncc(lm)) ijk=lm

c*****************************************************************
c
c     Construct the full cruise number by adding the integer
c    country code onto the left side of the cruise number
c
c*****************************************************************

      if ( icruise .ge. 0 ) then
       icnum = 1000000 * ijk + icruise
      else
       icnum = - (1000000 * ijk - icruise)
      endif

      return
      end

